Installation — django-ttag v1.0-alpha-2 documentation

# django-ttag v1.0-alpha-2 documentation

previous | next | index

# Installation

Before installing django-ttag, you’ll obviously need to have copy of Django installed. For the 1.0 release, Django 1.1 is required.

## Installing django-ttag

The easiest way is to use an automatic package-installation tools like pip.

Simply type:

    pip install django-ttag

### Manual installation

If you prefer not to use an automated package installer, you can download a copy of django-ttag and install it manually. The latest release package can be downloaded from django-ttag’s listing on the Python Package Index.

Once you’ve downloaded the package, unpack it and run the `setup.py` installation script:

    python setup.py install

## Configuring your project

There is nothing you need to do to configure django-ttag with your Django project. Once it’s installed, just start using it!

If, however you would like to run the standard django-ttag tests as part of your project tests then you can. In your project’s settings module, add django-ttag to your `INSTALLED_APPS` setting:

    INSTALLED_APPS = (
        ...
        'ttag',
    )